pub struct GroupSave {Show 15 fields
pub id: Vec<u8>,
pub created_at_ns: i64,
pub membership_state: i32,
pub installations_last_checked: i64,
pub added_by_inbox_id: String,
pub welcome_id: Option<i64>,
pub rotated_at_ns: i64,
pub conversation_type: i32,
pub dm_id: Option<String>,
pub last_message_ns: Option<i64>,
pub message_disappear_from_ns: Option<i64>,
pub message_disappear_in_ns: Option<i64>,
pub metadata: Option<ImmutableMetadataSave>,
pub mutable_metadata: Option<MutableMetadataSave>,
pub paused_for_version: Option<String>,
}Expand description
Proto representation of a stored group
Fields
id: Vec<u8>created_at_ns: i64membership_state: i32installations_last_checked: i64added_by_inbox_id: Stringwelcome_id: Option<i64>rotated_at_ns: i64conversation_type: i32dm_id: Option<String>last_message_ns: Option<i64>message_disappear_from_ns: Option<i64>message_disappear_in_ns: Option<i64>metadata: Option<ImmutableMetadataSave>metadata fields
mutable_metadata: Option<MutableMetadataSave>paused_for_version: Option<String>Implementations
Sourceimpl GroupSave
impl GroupSave
Sourcepub fn membership_state(&self) -> GroupMembershipStateSave
pub fn membership_state(&self) -> GroupMembershipStateSave
Returns the enum value of membership_state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_membership_state(&mut self, value: GroupMembershipStateSave)
pub fn set_membership_state(&mut self, value: GroupMembershipStateSave)
Sets membership_state to the provided enum value.
Sourcepub fn welcome_id(&self) -> i64
pub fn welcome_id(&self) -> i64
Returns the value of welcome_id, or the default value if welcome_id is unset.
Sourcepub fn conversation_type(&self) -> ConversationTypeSave
pub fn conversation_type(&self) -> ConversationTypeSave
Returns the enum value of conversation_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_conversation_type(&mut self, value: ConversationTypeSave)
pub fn set_conversation_type(&mut self, value: ConversationTypeSave)
Sets conversation_type to the provided enum value.
Sourcepub fn dm_id(&self) -> &str
pub fn dm_id(&self) -> &str
Returns the value of dm_id, or the default value if dm_id is unset.
Sourcepub fn last_message_ns(&self) -> i64
pub fn last_message_ns(&self) -> i64
Returns the value of last_message_ns, or the default value if last_message_ns is unset.
Sourcepub fn message_disappear_from_ns(&self) -> i64
pub fn message_disappear_from_ns(&self) -> i64
Returns the value of message_disappear_from_ns, or the default value if message_disappear_from_ns is unset.
Sourcepub fn message_disappear_in_ns(&self) -> i64
pub fn message_disappear_in_ns(&self) -> i64
Returns the value of message_disappear_in_ns, or the default value if message_disappear_in_ns is unset.
Sourcepub fn paused_for_version(&self) -> &str
pub fn paused_for_version(&self) -> &str
Returns the value of paused_for_version, or the default value if paused_for_version is unset.